@@ -38,14 +38,24 @@ common_opts = [
                default='/var/cache/ceilometer-instance-poller',
                help='Path where to store the cache of instance polled information.'),
     cfg.IntOpt('instance_info_cache_expiration',
-               default=60,
+               default=240,
                help='Time in minute for the instance information cache expiration.'),
     cfg.IntOpt('instance_info_cache_fuzzing',
-               default=30,
+               default=120,
                help='Time in minute to randomly add to instance_info_cache_expiration.'
                     ' The point is to not poll all instances at the same time.'),
 ]
 
+# Define your CLI-only options with boolean switches
+cli_only_opts = [
+    cfg.BoolOpt('use-cache-only',
+                default=False,
+                help='Only use cache data when available.'),
+    cfg.BoolOpt('do-not-print',
+                default=False,
+                help='Do not print the output of found values. Useful to only put data in cache in a cron.'),
+]
+
 def list_opts():
     return [
         ("DEFAULT", common_opts),
@@ -123,7 +133,7 @@ def _libvirt_disconnect(conn):
     conn.close()
 
 
-def _print_all(domains, expiration_timeout, cache_fuzzing, cache_path):
+def _print_all(domains, expiration_timeout, cache_fuzzing, cache_path, use_cache_only, do_not_print):
     if len(domains) == 0:
         LOG.debug("Empty list of domains: no VMs?")
         print('[]')
@@ -148,11 +158,14 @@ def _print_all(domains, expiration_timeout, cache_fuzzing, cache_path):
             instance_uuid = domain.UUIDString()
             instance_vcpus = domain.maxVcpus()
             LOG.debug(f"Found instance {instance_uuid} ({instance_vcpus} vcpus)")
-            exp = expiration_timeout + random.randrange(cache_fuzzing)
+            if use_cache_only:
+                exp = (expiration_timeout + cache_fuzzing) * 2
+            else:
+                exp = expiration_timeout + random.randrange(cache_fuzzing)
             cache = Cache(instance_uuid, cache_path, minutes=exp)
             metric = cache.check()
 
-            if metric is None :
+            if metric is None and not use_cache_only:
                 LOG.debug(f"No cahe for instance {instance_uuid}: will fetch the data using libgestfs.")
                 g = guestfs.GuestFS(python_return_dict=True)
 
@@ -307,26 +320,36 @@ def _print_all(domains, expiration_timeout, cache_fuzzing, cache_path):
                 g.umount_all()
                 g.close()
                 cache.store(metric)
+
             else:
                 LOG.debug(f"Using cache for instance {instance_uuid}")
 
-            if metrics != None:
+            if metrics != None and metric != None:
                 metrics.append(metric)
 
-        print(json.dumps(metrics))
-        return metrics
+
+        if do_not_print:
+            return metrics
+        else:
+            print(json.dumps(metrics))
+            return metrics
 
 def run_instance_poller():
     conf = cfg.ConfigOpts()
-    conf.register_cli_opts(common_opts)
+    conf.register_opts(common_opts)
+    conf.register_cli_opts(cli_only_opts)
     logging.register_options(conf)
-    conf(project='ceilometer-instance-poller')
+    conf(args=sys.argv[1:], project='ceilometer-instance-poller')
     logging.setup(conf, conf.project)
 
 
     conn = _libvirt_connect()
     domains = _list_all_domains(conn)
-    _print_all(domains, conf.instance_info_cache_expiration, conf.instance_info_cache_fuzzing, conf.instance_info_cache_path)
+    _print_all(domains, conf.instance_info_cache_expiration,
+                        conf.instance_info_cache_fuzzing,
+                        conf.instance_info_cache_path,
+                        conf.use_cache_only,
+                        conf.do_not_print)
     _libvirt_disconnect(conn)
 
 if __name__ == "__main__":
